# Ensembl

This is a collection of modules to query the ensembl database.

Currently there are the following APIs covered:

| Submodule | Description |
|-----------|-------------|
| [`search`](./ensembl/search.md) | Searches through descriptions on ENSEMBL|
| [`database`](./ensembl/database.md) | Prints all available databases on Ensembl's SQL database|
| [`lookup-id`](./ensembl/lookup-id.md) | Lookup information for genes/transcripts providing ensembl ids|
| [`lookup-symbol`](./ensembl/lookup-symbol.md) | Lookup information for genes/transcripts providing symbols and species|
| [`release`](./ensembl/release.md) | Retrieves the latest ensembl release version|
| [`ref`](./ensembl/ref.md) | Retrieves reference files from Ensembl FTP site|
| [`species`](./ensembl/species.md) | Retrieves the list of species from ENSEMBL FTP site|
